/* global navigator, Notification, localStorage */
import { initializeApp } from 'firebase/app';
import { getMessaging, getToken, onMessage } from "firebase/messaging";
import firebaseConfig from './firebase.json';


if( ! window.device ) {
    const app = initializeApp(firebaseConfig);
    const messaging = getMessaging(app);
    const firebaseWorking = ( isWorking ) => localStorage.setItem("firebase-browser-working", isWorking);
    firebaseWorking(false);
    if(navigator && 'serviceWorker' in navigator){
      navigator.serviceWorker.register("./firebase-browser/dist/firebase-sw-bundle.js").then( serviceWorkerRegistration => {
        Notification.requestPermission().then( permission => {
          if( permission === "granted") {
            getToken( messaging, {vapidKey: firebaseConfig.vapidKey, serviceWorkerRegistration}).then( token => {
              if(token){
                firebaseWorking(true);
                localStorage.setItem("firebase-browser-token", token);
              }
            });
          }
        });
      });
    }
    
    onMessage( messaging, payload => {
      // foreground push notification
    }, error => {
      console.error(error);
    });
}